@@ -8,8 +8,8 @@ PATH_TO_NODE = setting_overrides.get(
 )
 
 NODE_VERSION_COMMAND = setting_overrides.get(
-    'NPM_VERSION_ARGUMENT',
-    (PATH_TO_NODE, '--version',)
+    'NODE_VERSION_COMMAND',
+    '--version',
 )
 
 NODE_VERSION_FILTER = setting_overrides.get(
@@ -24,7 +24,7 @@ PATH_TO_NPM = setting_overrides.get(
 
 NPM_VERSION_COMMAND = setting_overrides.get(
     'NPM_VERSION_COMMAND',
-    (PATH_TO_NPM, '--version',)
+    '--version',
 )
 
 NPM_VERSION_FILTER = setting_overrides.get(
@@ -34,5 +34,15 @@ NPM_VERSION_FILTER = setting_overrides.get(
 
 NPM_INSTALL_COMMAND = setting_overrides.get(
     'NPM_INSTALL_COMMAND',
-    (PATH_TO_NPM, 'install',)
+    'install',
+)
+
+RAISE_ON_MISSING_DEPENDENCIES = setting_overrides.get(
+    'RAISE_ON_MISSING_DEPENDENCIES',
+    True,
+)
+
+RAISE_ON_OUTDATED_DEPENDENCIES = setting_overrides.get(
+    'RAISE_ON_OUTDATED_DEPENDENCIES',
+    True,
 )
\ No newline at end of file
